@@ -3,15 +3,20 @@ Definitions of the prior distributions of the embeddings.
 """
 import numpy as np
 import tensorflow as tf
+import networkx as nx
 import random, pickle
 import progressbar
 from .utils import dict_to_tf
 import warnings
 
 class Embedding:
+    '''
+    Generic class for probabilistic embeddings.
+    '''
     def __init__(self, vocabulary=None, dimensionality=100, lambda0=1.0, shared_context_vectors=True, saved_model_path=None):
         if saved_model_path is None:
-            assert isinstance(vocabulary, set)
+            if not isinstance(vocabulary, set):
+                raise TypeError("vocabulary must be a set")
             keys = list(vocabulary)
             if not shared_context_vectors:
                 keys = keys + list(set([key + "_c" for key in keys]))
@@ -28,6 +33,8 @@ class Embedding:
             self.theta = tf.Variable((np.random.rand(unique_parameters, dimensionality)- 0.5)/dimensionality, dtype=tf.float64)
             self.lambda0 = lambda0
         else:
+            if type(saved_model_path) != str:
+                raise TypeError("saved_model_path must be a str")
             with open(saved_model_path, "rb") as f:
                 d = pickle.load(f)
             self.vocabulary = d["vocabulary"]
@@ -51,10 +58,26 @@ class Embedding:
         return ix != -1
 
     def log_prob(self, batch_size, data_size):
+        """
+        Calculate the log (prior) probability of the embedding taking its current value
+        
+        Args:
+            batch_size (int): Batch size. Used to scale the log prob for the whole dataset.
+            data_size (int): Whole dataset size. Used to scale the log prob for the whole dataset.
+        
+        Returns:
+            Log probability as 1D tensor as tf.EagerTensor
+        """
         plain_loss = - 0.5 * tf.reduce_sum(tf.multiply(self.theta, self.theta)) * self.lambda0
         return (batch_size / data_size) * plain_loss
 
     def save(self, path):
+        """
+        Save embedding as a pickled file
+        
+        Args:
+            path (str): Path where the embedding is saved to as a str.
+        """
         theta = self.theta.numpy()
         d = {}
         d["theta"] = theta
@@ -69,17 +92,21 @@ class Embedding:
             pickle.dump(d, f)
 
 class LaplacianEmbedding(Embedding):
+    """
+    Probabilistic embedding with a Laplacian graph prior
+    """
     def __init__(self, vocabulary=None, dimensionality=100, graph=None, lambda0=1.0, lambda1=1.0, shared_context_vectors=True, saved_model_path=None):
         if saved_model_path is None:
+            if type(graph) != nx.Graph:
+                raise TypeError("graph must be a nx.Graph")
             self.lambda1 = lambda1
+            super().__init__(vocabulary, dimensionality, lambda0=lambda0, shared_context_vectors=shared_context_vectors)
             for wd in list(graph.nodes):
-                if wd in graph.nodes and wd not in vocabulary:
+                if wd in graph.nodes and wd not in self.vocabulary:
                     graph.remove_node(wd)
                     omitted_word_warning = f"'{wd}' does not exist in embedding vocabulary and will be omitted."
                     warnings.warn(omitted_word_warning)
-
             self.graph = graph
-            super().__init__(vocabulary, dimensionality, lambda0=lambda0, shared_context_vectors=shared_context_vectors)
         else:
             with open(saved_model_path, "rb") as f:
                 d = pickle.load(f)
@@ -91,6 +118,16 @@ class LaplacianEmbedding(Embedding):
             self.graph = d["graph"]
 
     def log_prob(self, batch_size, data_size):
+        """
+        Calculate the log (prior) probability of the embedding taking its current value
+        
+        Args:
+            batch_size (int): Batch size. Used to scale the log prob for the whole dataset.
+            data_size (int): Whole dataset size. Used to scale the log prob for the whole dataset.
+        
+        Returns:
+            Log probability as tf.EagerTensor
+        """
         g = self.graph
         triple = [(e_i, e_j, g[e_i][e_j].get("weight", 1.0)) for e_i, e_j in g.edges]
         edges_i, edges_j, weights = zip(*triple)
