@@ -5,6 +5,12 @@ from .utils import dict_to_tf, transitive_dict
 def filter_rare_words(data, limit=5):
     """
     Filter out words that only occur a handful of times
+    
+    Args:
+        data (list): list of strs
+    
+    Returns:
+        data, counts: list of strs and word counts as a dict
     """
     counts = {}
     if isinstance(data[0], list):
@@ -21,12 +27,21 @@ def filter_rare_words(data, limit=5):
             counts[wd] = counts.get(wd, 0) + 1
             
         outdata = [wd for wd in data if counts[wd] >= limit]
+    counts = {wd: count for wd, count in counts.items() if count >= limit}
     return outdata, counts
 
 def downsample_common_words(data, counts, cutoff=0.00001):
     """
     Discard words with the probability of 1 - sqrt(10^-5 / freq)
     Initially proposed by Mikolov et al. (2013)
+    
+    Args:
+        data (Union[list, tf.Tensor]): list of strs or tf.Tensor of strings
+        counts (dict): word counts in the dataset
+        cutoff (float): lowest word frequency for when downsampling is applied
+    
+    Returns:
+        list of strs
     """
     if not isinstance(data, tf.Tensor):
         data = tf.constant(data)
@@ -46,6 +61,15 @@ def downsample_common_words(data, counts, cutoff=0.00001):
     return [wd.decode("utf-8") for wd in newdata.numpy()]
 
 def preprocess_standard(text):
+    """
+    Standard preprocessing: filter out rare (<=5 occurences) words, downsample common words.
+
+    Args:
+        text (list): text as a list of strs
+
+    Returns:
+        text, vocabulary: text as a list of strs, vocabulary as a set of strs
+    """
     text, counts = filter_rare_words(text)
     text = downsample_common_words(text, counts)
 
